_`umbra.processing`
===================

.. automodule:: umbra.processing

Module Attributes
-----------------

.. attribute:: umbra.processing.LOGGER

.. attribute:: umbra.processing.UI_FILE

Classes
-------

.. autoclass:: Processing
	:show-inheritance:
	:members:

